"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collectionresponse import CollectionResponse, CollectionResponseTypedDict
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class ListCollectionsRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""


class ListCollectionsRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""


class ListCollectionsResponseTypedDict(TypedDict):
    r"""A list of collections matched with a projectName."""

    collections: List[CollectionResponseTypedDict]


class ListCollectionsResponse(BaseModel):
    r"""A list of collections matched with a projectName."""

    collections: List[CollectionResponse]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class QueryCollectionRequestBodyTypedDict(TypedDict):
    size: int
    r"""Number of documents to return. Note that the maximum number of documents is 100."""
    query: NotRequired[Dict[str, Any]]
    r"""Query object."""
    consistent_read: NotRequired[bool]
    r"""If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value."""
    include_vectors: NotRequired[bool]
    r"""If your application need to include vector values in the response, set includeVectors to true."""
    sort: NotRequired[List[Dict[str, Any]]]
    r"""List of field name, sort direction pairs."""
    fields: NotRequired[List[str]]
    r"""List of field name to include in results"""


class QueryCollectionRequestBody(BaseModel):
    size: int
    r"""Number of documents to return. Note that the maximum number of documents is 100."""

    query: Optional[Dict[str, Any]] = None
    r"""Query object."""

    consistent_read: Annotated[
        Optional[bool], pydantic.Field(alias="consistentRead")
    ] = False
    r"""If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value."""

    include_vectors: Annotated[
        Optional[bool], pydantic.Field(alias="includeVectors")
    ] = False
    r"""If your application need to include vector values in the response, set includeVectors to true."""

    sort: Optional[List[Dict[str, Any]]] = None
    r"""List of field name, sort direction pairs."""

    fields: Optional[List[str]] = None
    r"""List of field name to include in results"""


class QueryCollectionRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""
    request_body: QueryCollectionRequestBodyTypedDict


class QueryCollectionRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""

    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        QueryCollectionRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class QueryCollectionDocTypedDict(TypedDict):
    collection: str
    r"""Collection name."""
    score: float
    r"""Document similarity score."""
    doc: Dict[str, Any]


class QueryCollectionDoc(BaseModel):
    collection: str
    r"""Collection name."""

    score: float
    r"""Document similarity score."""

    doc: Dict[str, Any]


class QueryCollectionResponseTypedDict(TypedDict):
    r"""Documents selected by query."""

    took: int
    r"""Elapsed time in milliseconds."""
    max_score: float
    r"""Maximum score."""
    total: int
    r"""Total number of documents returned."""
    docs: List[QueryCollectionDocTypedDict]
    r"""List of documents."""


class QueryCollectionResponse(BaseModel):
    r"""Documents selected by query."""

    took: int
    r"""Elapsed time in milliseconds."""

    max_score: Annotated[float, pydantic.Field(alias="maxScore")]
    r"""Maximum score."""

    total: int
    r"""Total number of documents returned."""

    docs: List[QueryCollectionDoc]
    r"""List of documents."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Any, Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteDocsRequestBodyTypedDict(TypedDict):
    ids: NotRequired[List[str]]
    r"""A list of document IDs."""
    filter_: NotRequired[Dict[str, Any]]
    r"""Query filter."""


class DeleteDocsRequestBody(BaseModel):
    ids: Optional[List[str]] = None
    r"""A list of document IDs."""

    filter_: Annotated[Optional[Dict[str, Any]], pydantic.Field(alias="filter")] = None
    r"""Query filter."""


class DeleteDocsRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""
    request_body: DeleteDocsRequestBodyTypedDict


class DeleteDocsRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""

    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        DeleteDocsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class BulkUpsertDocsRequestBodyTypedDict(TypedDict):
    object_key: str
    r"""Object key uploaded based on bulk upsert info."""


class BulkUpsertDocsRequestBody(BaseModel):
    object_key: Annotated[str, pydantic.Field(alias="objectKey")]
    r"""Object key uploaded based on bulk upsert info."""


class BulkUpsertDocsRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""
    request_body: BulkUpsertDocsRequestBodyTypedDict


class BulkUpsertDocsRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""

    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        BulkUpsertDocsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from lambdadb.types import BaseModel
from typing import List, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


class Type(str, Enum):
    KEYWORD = "keyword"
    LONG = "long"
    DOUBLE = "double"
    DATETIME = "datetime"
    BOOLEAN = "boolean"
    SPARSE_VECTOR = "sparseVector"


class IndexConfigsTypedDict(TypedDict):
    r"""Types that do not need additional parameters."""

    type: Type


class IndexConfigs(BaseModel):
    r"""Types that do not need additional parameters."""

    type: Type


class TypeVector(str, Enum):
    VECTOR = "vector"


class Similarity(str, Enum):
    r"""Vector similarity metric."""

    COSINE = "cosine"
    L2_NORM = "l2_norm"
    DOT_PRODUCT = "dot_product"
    MAX_INNER_PRODUCT = "max_inner_product"


class IndexConfigsVectorTypedDict(TypedDict):
    type: TypeVector
    dimensions: int
    r"""Vector dimensions."""
    similarity: NotRequired[Similarity]
    r"""Vector similarity metric."""


class IndexConfigsVector(BaseModel):
    type: TypeVector

    dimensions: int
    r"""Vector dimensions."""

    similarity: Optional[Similarity] = Similarity.COSINE
    r"""Vector similarity metric."""


class TypeText(str, Enum):
    TEXT = "text"


class Analyzer(str, Enum):
    STANDARD = "standard"
    KOREAN = "korean"
    JAPANESE = "japanese"
    ENGLISH = "english"


class IndexConfigsTextTypedDict(TypedDict):
    type: TypeText
    analyzers: NotRequired[List[Analyzer]]
    r"""Analyzers."""


class IndexConfigsText(BaseModel):
    type: TypeText

    analyzers: Optional[List[Analyzer]] = None
    r"""Analyzers."""


IndexConfigsUnionTypedDict = TypeAliasType(
    "IndexConfigsUnionTypedDict",
    Union[
        IndexConfigsTypedDict, IndexConfigsTextTypedDict, IndexConfigsVectorTypedDict
    ],
)


IndexConfigsUnion = TypeAliasType(
    "IndexConfigsUnion", Union[IndexConfigs, IndexConfigsText, IndexConfigsVector]
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .apierror import APIError
    from .badrequest_error import BadRequestError, BadRequestErrorData
    from .internalservererror import InternalServerError, InternalServerErrorData
    from .lambdadberror import LambdaDBError
    from .no_response_error import NoResponseError
    from .resourcealreadyexists_error import (
        ResourceAlreadyExistsError,
        ResourceAlreadyExistsErrorData,
    )
    from .resourcenotfound_error import ResourceNotFoundError, ResourceNotFoundErrorData
    from .responsevalidationerror import ResponseValidationError
    from .toomanyrequests_error import TooManyRequestsError, TooManyRequestsErrorData
    from .unauthenticated_error import UnauthenticatedError, UnauthenticatedErrorData

__all__ = [
    "APIError",
    "BadRequestError",
    "BadRequestErrorData",
    "InternalServerError",
    "InternalServerErrorData",
    "LambdaDBError",
    "NoResponseError",
    "ResourceAlreadyExistsError",
    "ResourceAlreadyExistsErrorData",
    "ResourceNotFoundError",
    "ResourceNotFoundErrorData",
    "ResponseValidationError",
    "TooManyRequestsError",
    "TooManyRequestsErrorData",
    "UnauthenticatedError",
    "UnauthenticatedErrorData",
]

_dynamic_imports: dict[str, str] = {
    "APIError": ".apierror",
    "BadRequestError": ".badrequest_error",
    "BadRequestErrorData": ".badrequest_error",
    "InternalServerError": ".internalservererror",
    "InternalServerErrorData": ".internalservererror",
    "LambdaDBError": ".lambdadberror",
    "NoResponseError": ".no_response_error",
    "ResourceAlreadyExistsError": ".resourcealreadyexists_error",
    "ResourceAlreadyExistsErrorData": ".resourcealreadyexists_error",
    "ResourceNotFoundError": ".resourcenotfound_error",
    "ResourceNotFoundErrorData": ".resourcenotfound_error",
    "ResponseValidationError": ".responsevalidationerror",
    "TooManyRequestsError": ".toomanyrequests_error",
    "TooManyRequestsErrorData": ".toomanyrequests_error",
    "UnauthenticatedError": ".unauthenticated_error",
    "UnauthenticatedErrorData": ".unauthenticated_error",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .httpclient import AsyncHttpClient, ClientOwner, HttpClient, close_clients
from .sdkconfiguration import SDKConfiguration
from .utils.logger import Logger, get_default_logger
from .utils.retries import RetryConfig
import httpx
import importlib
from lambdadb import models, utils
from lambdadb._hooks import SDKHooks
from lambdadb.types import OptionalNullable, UNSET
from typing import Any, Callable, Dict, Optional, TYPE_CHECKING, Union, cast
import weakref

if TYPE_CHECKING:
    from lambdadb.collections import Collections


class LambdaDB(BaseSDK):
    r"""LambdaDB API: LambdaDB Open API Spec"""

    collections: "Collections"
    _sub_sdk_map = {
        "collections": ("lambdadb.collections", "Collections"),
    }

    def __init__(
        self,
        project_api_key: Optional[
            Union[Optional[str], Callable[[], Optional[str]]]
        ] = None,
        server_idx: Optional[int] = None,
        server_url: Optional[str] = None,
        url_params: Optional[Dict[str, str]] = None,
        client: Optional[HttpClient] = None,
        async_client: Optional[AsyncHttpClient] = None,
        retry_config: OptionalNullable[RetryConfig] = UNSET,
        timeout_ms: Optional[int] = None,
        debug_logger: Optional[Logger] = None,
    ) -> None:
        r"""Instantiates the SDK configuring it with the provided parameters.

        :param project_api_key: The project_api_key required for authentication
        :param server_idx: The index of the server to use for all methods
        :param server_url: The server URL to use for all methods
        :param url_params: Parameters to optionally template the server URL with
        :param client: The HTTP client to use for all synchronous methods
        :param async_client: The Async HTTP client to use for all asynchronous methods
        :param retry_config: The retry configuration to use for all supported methods
        :param timeout_ms: Optional request timeout applied to each operation in milliseconds
        """
        client_supplied = True
        if client is None:
            client = httpx.Client()
            client_supplied = False

        assert issubclass(
            type(client), HttpClient
        ), "The provided client must implement the HttpClient protocol."

        async_client_supplied = True
        if async_client is None:
            async_client = httpx.AsyncClient()
            async_client_supplied = False

        if debug_logger is None:
            debug_logger = get_default_logger()

        assert issubclass(
            type(async_client), AsyncHttpClient
        ), "The provided async_client must implement the AsyncHttpClient protocol."

        security: Any = None
        if callable(project_api_key):
            # pylint: disable=unnecessary-lambda-assignment
            security = lambda: models.Security(project_api_key=project_api_key())
        else:
            security = models.Security(project_api_key=project_api_key)

        if server_url is not None:
            if url_params is not None:
                server_url = utils.template_url(server_url, url_params)

        BaseSDK.__init__(
            self,
            SDKConfiguration(
                client=client,
                client_supplied=client_supplied,
                async_client=async_client,
                async_client_supplied=async_client_supplied,
                security=security,
                server_url=server_url,
                server_idx=server_idx,
                retry_config=retry_config,
                timeout_ms=timeout_ms,
                debug_logger=debug_logger,
            ),
        )

        hooks = SDKHooks()

        # pylint: disable=protected-access
        self.sdk_configuration.__dict__["_hooks"] = hooks

        self.sdk_configuration = hooks.sdk_init(self.sdk_configuration)

        weakref.finalize(
            self,
            close_clients,
            cast(ClientOwner, self.sdk_configuration),
            self.sdk_configuration.client,
            self.sdk_configuration.client_supplied,
            self.sdk_configuration.async_client,
            self.sdk_configuration.async_client_supplied,
        )

    def __getattr__(self, name: str):
        if name in self._sub_sdk_map:
            module_path, class_name = self._sub_sdk_map[name]
            try:
                module = importlib.import_module(module_path)
                klass = getattr(module, class_name)
                instance = klass(self.sdk_configuration)
                setattr(self, name, instance)
                return instance
            except ImportError as e:
                raise AttributeError(
                    f"Failed to import module {module_path} for attribute {name}: {e}"
                ) from e
            except AttributeError as e:
                raise AttributeError(
                    f"Failed to find class {class_name} in module {module_path} for attribute {name}: {e}"
                ) from e

        raise AttributeError(
            f"'{type(self).__name__}' object has no attribute '{name}'"
        )

    def __dir__(self):
        default_attrs = list(super().__dir__())
        lazy_attrs = list(self._sub_sdk_map.keys())
        return sorted(list(set(default_attrs + lazy_attrs)))

    def __enter__(self):
        return self

    async def __aenter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.client is not None
            and not self.sdk_configuration.client_supplied
        ):
            self.sdk_configuration.client.close()
        self.sdk_configuration.client = None

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        if (
            self.sdk_configuration.async_client is not None
            and not self.sdk_configuration.async_client_supplied
        ):
            await self.sdk_configuration.async_client.aclose()
        self.sdk_configuration.async_client = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetBulkUpsertDocsRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""


class GetBulkUpsertDocsRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""

    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""


class GetBulkUpsertDocsType(str, Enum):
    r"""Content type that must be specified when uploading documents."""

    APPLICATION_JSON = "application/json"


class HTTPMethod(str, Enum):
    r"""HTTP method that must be specified when uploading documents."""

    PUT = "PUT"


class GetBulkUpsertDocsResponseTypedDict(TypedDict):
    r"""Required info to upload documents."""

    url: str
    r"""Presigned URL."""
    object_key: str
    r"""Object key that must be specified when uploading documents."""
    type: NotRequired[GetBulkUpsertDocsType]
    r"""Content type that must be specified when uploading documents."""
    http_method: NotRequired[HTTPMethod]
    r"""HTTP method that must be specified when uploading documents."""
    size_limit_bytes: NotRequired[int]
    r"""Object size limit in bytes."""


class GetBulkUpsertDocsResponse(BaseModel):
    r"""Required info to upload documents."""

    url: str
    r"""Presigned URL."""

    object_key: Annotated[str, pydantic.Field(alias="objectKey")]
    r"""Object key that must be specified when uploading documents."""

    type: Optional[GetBulkUpsertDocsType] = GetBulkUpsertDocsType.APPLICATION_JSON
    r"""Content type that must be specified when uploading documents."""

    http_method: Annotated[Optional[HTTPMethod], pydantic.Field(alias="httpMethod")] = (
        HTTPMethod.PUT
    )
    r"""HTTP method that must be specified when uploading documents."""

    size_limit_bytes: Annotated[
        Optional[int], pydantic.Field(alias="sizeLimitBytes")
    ] = 209715200
    r"""Object size limit in bytes."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collectionresponse import CollectionResponse, CollectionResponseTypedDict
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class GetCollectionRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""


class GetCollectionRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""

    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""


class GetCollectionResponseTypedDict(TypedDict):
    r"""Describe collection success."""

    collection: CollectionResponseTypedDict


class GetCollectionResponse(BaseModel):
    r"""Describe collection success."""

    collection: CollectionResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from .sdkconfiguration import SDKConfiguration
from lambdadb import errors, models, utils
from lambdadb._hooks import HookContext
from lambdadb.docs import Docs
from lambdadb.types import OptionalNullable, UNSET
from lambdadb.utils import get_security_from_env
from typing import Any, Dict, List, Mapping, Optional, Union


class Collections(BaseSDK):
    docs: Docs

    def __init__(self, sdk_config: SDKConfiguration) -> None:
        BaseSDK.__init__(self, sdk_config)
        self.sdk_configuration = sdk_config
        self._init_sdks()

    def _init_sdks(self):
        self.docs = Docs(self.sdk_configuration)

    def list(
        self,
        *,
        project_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListCollectionsResponse:
        r"""List all collections in an existing project.

        :param project_name: Project name.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListCollectionsRequest(
            project_name=project_name,
        )

        req = self._build_request(
            method="GET",
            path="/projects/{projectName}/collections",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listCollections",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json_response(
                models.ListCollectionsResponse, http_res
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        project_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ListCollectionsResponse:
        r"""List all collections in an existing project.

        :param project_name: Project name.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ListCollectionsRequest(
            project_name=project_name,
        )

        req = self._build_request_async(
            method="GET",
            path="/projects/{projectName}/collections",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listCollections",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json_response(
                models.ListCollectionsResponse, http_res
            )
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def create(
        self,
        *,
        project_name: str,
        collection_name: str,
        index_configs: Optional[
            Union[
                Dict[str, models.IndexConfigsUnion],
                Dict[str, models.IndexConfigsUnionTypedDict],
            ]
        ] = None,
        source_project_name: Optional[str] = None,
        source_collection_name: Optional[str] = None,
        source_datetime: Optional[str] = None,
        source_project_api_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CreateCollectionResponse:
        r"""Create a collection.

        :param project_name: Project name.
        :param collection_name: Collection name must be unique within a project and the supported maximum length is 52.
        :param index_configs:
        :param source_project_name:
        :param source_collection_name:
        :param source_datetime:
        :param source_project_api_key:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CreateCollectionRequest(
            project_name=project_name,
            request_body=models.CreateCollectionRequestBody(
                collection_name=collection_name,
                index_configs=utils.get_pydantic_model(
                    index_configs, Optional[Dict[str, models.IndexConfigsUnion]]
                ),
                source_project_name=source_project_name,
                source_collection_name=source_collection_name,
                source_datetime=source_datetime,
                source_project_api_key=source_project_api_key,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/projects/{projectName}/collections",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.CreateCollectionRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "409", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return utils.unmarshal_json_response(
                models.CreateCollectionResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceAlreadyExistsErrorData, http_res
            )
            raise errors.ResourceAlreadyExistsError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        project_name: str,
        collection_name: str,
        index_configs: Optional[
            Union[
                Dict[str, models.IndexConfigsUnion],
                Dict[str, models.IndexConfigsUnionTypedDict],
            ]
        ] = None,
        source_project_name: Optional[str] = None,
        source_collection_name: Optional[str] = None,
        source_datetime: Optional[str] = None,
        source_project_api_key: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.CreateCollectionResponse:
        r"""Create a collection.

        :param project_name: Project name.
        :param collection_name: Collection name must be unique within a project and the supported maximum length is 52.
        :param index_configs:
        :param source_project_name:
        :param source_collection_name:
        :param source_datetime:
        :param source_project_api_key:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.CreateCollectionRequest(
            project_name=project_name,
            request_body=models.CreateCollectionRequestBody(
                collection_name=collection_name,
                index_configs=utils.get_pydantic_model(
                    index_configs, Optional[Dict[str, models.IndexConfigsUnion]]
                ),
                source_project_name=source_project_name,
                source_collection_name=source_collection_name,
                source_datetime=source_datetime,
                source_project_api_key=source_project_api_key,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/projects/{projectName}/collections",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.CreateCollectionRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "409", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return utils.unmarshal_json_response(
                models.CreateCollectionResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "409", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceAlreadyExistsErrorData, http_res
            )
            raise errors.ResourceAlreadyExistsError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def delete(
        self,
        *,
        project_name: str,
        collection_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Delete an existing collection.

        :param project_name: Project name.
        :param collection_name: Collection name.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteCollectionRequest(
            project_name=project_name,
            collection_name=collection_name,
        )

        req = self._build_request(
            method="DELETE",
            path="/projects/{projectName}/collections/{collectionName}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return utils.unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def delete_async(
        self,
        *,
        project_name: str,
        collection_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.MessageResponse:
        r"""Delete an existing collection.

        :param project_name: Project name.
        :param collection_name: Collection name.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.DeleteCollectionRequest(
            project_name=project_name,
            collection_name=collection_name,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/projects/{projectName}/collections/{collectionName}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="deleteCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "202", "application/json"):
            return utils.unmarshal_json_response(models.MessageResponse, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def get(
        self,
        *,
        project_name: str,
        collection_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetCollectionResponse:
        r"""Get metadata of an existing collection.

        :param project_name: Project name.
        :param collection_name: Collection name.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetCollectionRequest(
            project_name=project_name,
            collection_name=collection_name,
        )

        req = self._build_request(
            method="GET",
            path="/projects/{projectName}/collections/{collectionName}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json_response(models.GetCollectionResponse, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def get_async(
        self,
        *,
        project_name: str,
        collection_name: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.GetCollectionResponse:
        r"""Get metadata of an existing collection.

        :param project_name: Project name.
        :param collection_name: Collection name.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.GetCollectionRequest(
            project_name=project_name,
            collection_name=collection_name,
        )

        req = self._build_request_async(
            method="GET",
            path="/projects/{projectName}/collections/{collectionName}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json_response(models.GetCollectionResponse, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def update(
        self,
        *,
        project_name: str,
        collection_name: str,
        index_configs: Union[
            Dict[str, models.IndexConfigsUnion],
            Dict[str, models.IndexConfigsUnionTypedDict],
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.UpdateCollectionResponse:
        r"""Configure a collection.

        :param project_name: Project name.
        :param collection_name: Collection name.
        :param index_configs:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpdateCollectionRequest(
            project_name=project_name,
            collection_name=collection_name,
            request_body=models.UpdateCollectionRequestBody(
                index_configs=utils.get_pydantic_model(
                    index_configs, Dict[str, models.IndexConfigsUnion]
                ),
            ),
        )

        req = self._build_request(
            method="PATCH",
            path="/projects/{projectName}/collections/{collectionName}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.UpdateCollectionRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="updateCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json_response(
                models.UpdateCollectionResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def update_async(
        self,
        *,
        project_name: str,
        collection_name: str,
        index_configs: Union[
            Dict[str, models.IndexConfigsUnion],
            Dict[str, models.IndexConfigsUnionTypedDict],
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.UpdateCollectionResponse:
        r"""Configure a collection.

        :param project_name: Project name.
        :param collection_name: Collection name.
        :param index_configs:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.UpdateCollectionRequest(
            project_name=project_name,
            collection_name=collection_name,
            request_body=models.UpdateCollectionRequestBody(
                index_configs=utils.get_pydantic_model(
                    index_configs, Dict[str, models.IndexConfigsUnion]
                ),
            ),
        )

        req = self._build_request_async(
            method="PATCH",
            path="/projects/{projectName}/collections/{collectionName}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.UpdateCollectionRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="updateCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json_response(
                models.UpdateCollectionResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def query(
        self,
        *,
        project_name: str,
        collection_name: str,
        size: int,
        query: Optional[Dict[str, Any]] = None,
        consistent_read: Optional[bool] = False,
        include_vectors: Optional[bool] = False,
        sort: Optional[List[Dict[str, Any]]] = None,
        fields: Optional[List[str]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.QueryCollectionResponse:
        r"""Search a collection with a query and return the most similar documents.

        :param project_name: Project name.
        :param collection_name: Collection name.
        :param size: Number of documents to return. Note that the maximum number of documents is 100.
        :param query: Query object.
        :param consistent_read: If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value.
        :param include_vectors: If your application need to include vector values in the response, set includeVectors to true.
        :param sort: List of field name, sort direction pairs.
        :param fields: List of field name to include in results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.QueryCollectionRequest(
            project_name=project_name,
            collection_name=collection_name,
            request_body=models.QueryCollectionRequestBody(
                size=size,
                query=query,
                consistent_read=consistent_read,
                include_vectors=include_vectors,
                sort=sort,
                fields=fields,
            ),
        )

        req = self._build_request(
            method="POST",
            path="/projects/{projectName}/collections/{collectionName}/query",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.QueryCollectionRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="queryCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json_response(
                models.QueryCollectionResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def query_async(
        self,
        *,
        project_name: str,
        collection_name: str,
        size: int,
        query: Optional[Dict[str, Any]] = None,
        consistent_read: Optional[bool] = False,
        include_vectors: Optional[bool] = False,
        sort: Optional[List[Dict[str, Any]]] = None,
        fields: Optional[List[str]] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.QueryCollectionResponse:
        r"""Search a collection with a query and return the most similar documents.

        :param project_name: Project name.
        :param collection_name: Collection name.
        :param size: Number of documents to return. Note that the maximum number of documents is 100.
        :param query: Query object.
        :param consistent_read: If your application requires a strongly consistent read, set consistentRead to true. Although a strongly consistent read might take more time than an eventually consistent read, it always returns the last updated value.
        :param include_vectors: If your application need to include vector values in the response, set includeVectors to true.
        :param sort: List of field name, sort direction pairs.
        :param fields: List of field name to include in results
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.QueryCollectionRequest(
            project_name=project_name,
            collection_name=collection_name,
            request_body=models.QueryCollectionRequestBody(
                size=size,
                query=query,
                consistent_read=consistent_read,
                include_vectors=include_vectors,
                sort=sort,
                fields=fields,
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/projects/{projectName}/collections/{collectionName}/query",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.request_body,
                False,
                False,
                "json",
                models.QueryCollectionRequestBody,
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config
            else:
                retries = utils.RetryConfig(
                    "backoff", utils.BackoffStrategy(500, 60000, 1.5, 3600000), True
                )

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "5XX"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="queryCollection",
                oauth2_scopes=[],
                security_source=get_security_from_env(
                    self.sdk_configuration.security, models.Security
                ),
            ),
            request=req,
            error_status_codes=["400", "401", "404", "429", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return utils.unmarshal_json_response(
                models.QueryCollectionResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.BadRequestErrorData, http_res
            )
            raise errors.BadRequestError(response_data, http_res)
        if utils.match_response(http_res, "401", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.UnauthenticatedErrorData, http_res
            )
            raise errors.UnauthenticatedError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.ResourceNotFoundErrorData, http_res
            )
            raise errors.ResourceNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "429", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.TooManyRequestsErrorData, http_res
            )
            raise errors.TooManyRequestsError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = utils.unmarshal_json_response(
                errors.InternalServerErrorData, http_res
            )
            raise errors.InternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)
